@@ -1,6 +1,8 @@
 package Devel::IPerl::ExecutionResult;
-$Devel::IPerl::ExecutionResult::VERSION = '0.001';
+$Devel::IPerl::ExecutionResult::VERSION = '0.002';
 use strict;
+use warnings;
+
 use Moo;
 use MooX::HandlesVia;
 
@@ -8,6 +10,16 @@ use MooX::HandlesVia;
 # can only be "ok", "error", or "abort"
 has status => ( is => 'rw' );
 
+has stdout => ( is => 'rw' );
+
+has stderr => ( is => 'rw' );
+
+has last_output => ( is => 'rw' );
+
+has error => ( is => 'rw' );
+
+has results => ( is => 'rw', default => sub { [] } );
+
 use constant {
 	STATUS_OK    => 'ok',
 	STATUS_ERROR => 'error',
@@ -40,7 +52,7 @@ Devel::IPerl::ExecutionResult
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
